﻿# Finds, lists, and removes JPEGs from RAW+JPEG pairs.
#
# Version 1.0
# 
# The script finds RAW+JPEG pairs by seraching directories looking for RAW files ending in
# ".cr2", ".nef", or ".dng" then testing to see if a ".jpg" exists with the same base name
# in that directory.
# Files with identical names in separate directories will not be selected or removed.
#
# By default this script will not remove files, verify files flagged for removal are correct
# before answering yes at the prompt. File deletions are perminate and can not be undone.
 
$Path = $PSScriptRoot
$remove = $false
$parisFound = $false

$logFile = "$Path\raw+jpeg.log"
Remove-Item $logFile -ErrorAction SilentlyContinue

$test = Read-Host "Remove JPEGs from RAW+JPEG pairs (y/n) [n]"
if( $test.CompareTo("y") -eq 0 ) {
    $remove = $true
    echo "Will delete matches when found."
}

$dirs = @(gi $path) + @(gci $path -Directory -Recurse)

$dirs | foreach-object {
    $searchPath = $_.FullName
    
    $jobs = gci "$searchPath\*.*" -include *.cr2,*.cr3,*.dng,*.nef,*.arw | select -expand basename | sort -unique

    $jobs | foreach-object {
	    if( ((Test-Path -path "$searchPath\$_.cr2") -and (Test-Path -path "$searchPath\$_.jpg")) -or 
			((Test-Path -path "$searchPath\$_.cr3") -and (Test-Path -path "$searchPath\$_.jpg")) -or 
            ((Test-Path -path "$searchPath\$_.nef") -and (Test-Path -path "$searchPath\$_.jpg" )) -or
            ((Test-Path -path "$searchPath\$_.arw") -and (Test-Path -path "$searchPath\$_.jpg")) -or 
            ((Test-Path -path "$searchPath\$_.dng") -and (Test-Path -path "$searchPath\$_.jpg" ))
          )
	    {
			$pairsFound = $true;
            echo "Matches: $searchPath\$_.jpg" | Tee-Object $logFile -Append
            if( $remove ) {
                echo "Removing: $searchPath\$_.jpg" | Tee-Object $logFile -Append
                Remove-Item $searchPath\$_.jpg
            }
	    }
    }
}

if( -not $pairsFound ) {
	echo "No RAW+JPEG pairs found."
	sleep 1
}
